Module: NetzkeCommunitypack
- Defined in:
- lib/netzke-communitypack.rb,
lib/netzke-communitypack/version.rb
Constant Summary collapse
- VERSION =
Keep the major and minor versions synced with those of Netzke Core gem.
"0.7.0"
Keep the major and minor versions synced with those of Netzke Core gem.
"0.7.0"